@@ -14,7 +14,6 @@ from tqdm.auto import tqdm
 
 from .shape import _circle_radius
 
-
 __all__ = [
     "Area",
     "Perimeter",
@@ -462,7 +461,7 @@ class AverageCharacter:
                 if "median" in mode:
                     medians.append(np.median(values_list))
                 if "mode" in mode:
-                    modes.append(sp.stats.mode(values_list)[0][0])
+                    modes.append(sp.stats.mode(values_list, keepdims=False)[0])
 
             else:
                 if "mean" in mode:
@@ -638,8 +637,21 @@ class StreetProfile:
                 np.nanmean(rights) if ~np.isnan(rights).all() else tick_length / 2
             )
             widths.append(np.mean([left_mean, right_mean]) * 2)
-            openness.append(np.isnan(s).sum() / (f).sum())
-            deviations.append(np.nanstd(s))
+
+            f_sum = (f).sum()
+            s_nan = np.isnan(s)
+
+            if not f_sum:
+                openness_score = np.nan
+            else:
+                openness_score = s_nan.sum() / f_sum
+            openness.append(openness_score)
+
+            if s_nan.all():
+                deviation_score = np.nan
+            else:
+                deviation_score = np.nanstd(s)
+            deviations.append(deviation_score)
 
             if do_heights:
                 b = blgs[f]
