@@ -3,14 +3,15 @@
 
 # elements.py
 # generating derived elements (street edge, block)
-from distutils.version import LooseVersion
+import warnings
 
 import geopandas as gpd
 import libpysal
-import warnings
 import numpy as np
-import pygeos
 import pandas as pd
+import pygeos
+
+from packaging.version import Version
 from scipy.spatial import Voronoi
 from shapely.geometry.base import BaseGeometry
 from shapely.ops import polygonize
@@ -26,7 +27,7 @@ __all__ = [
     "get_network_ratio",
 ]
 
-GPD_10 = str(gpd.__version__) >= LooseVersion("0.10")
+GPD_10 = Version(gpd.__version__) >= Version("0.10")
 
 
 def buffered_limit(gdf, buffer=100):
@@ -507,9 +508,7 @@ class Tessellation:
         clean_blocks.loc[single, "uID"] = clean_blocks.loc[single, "position"].apply(
             lambda ix: buildings.iloc[res[inp == ix][0]][unique_id]
         )
-        tessellation = pd.concat(new)
-
-        return tessellation.append(clean_blocks.drop(columns="position")).reset_index(
+        return pd.concat(new + [clean_blocks.drop(columns="position")]).reset_index(
             drop=True
         )
 
@@ -551,10 +550,10 @@ class Tessellation:
 
 class Blocks:
     """
-    Generate blocks based on buildings, tesselation and street network.
+    Generate blocks based on buildings, tessellation, and street network.
 
     Dissolves tessellation cells based on street-network based polygons.
-    Links resulting id to ``buildings`` and ``tesselation`` as attributes.
+    Links resulting id to ``buildings`` and ``tessellation`` as attributes.
 
     Parameters
     ----------
@@ -593,19 +592,6 @@ class Blocks:
     Examples
     --------
     >>> blocks = mm.Blocks(tessellation_df, streets_df, buildings_df, 'bID', 'uID')
-    Buffering streets...
-    Generating spatial index...
-    Difference...
-    Defining adjacency...
-    Defining street-based blocks...
-    Defining block ID...
-    Generating centroids...
-    Spatial join...
-    Attribute join (tesselation)...
-    Generating blocks...
-    Multipart to singlepart...
-    Attribute join (buildings)...
-    Attribute join (tesselation)...
     >>> blocks.blocks.head()
         bID	geometry
     0	1.0	POLYGON ((1603560.078648818 6464202.366899694,...
@@ -647,14 +633,14 @@ class Blocks:
                 buildings_c,
                 cut[[cut.geometry.name, "component"]],
                 how="left",
-                predicate="intersects",
+                predicate="within",
             )
         else:
             centroids_tempID = gpd.sjoin(
                 buildings_c,
                 cut[[cut.geometry.name, "component"]],
                 how="left",
-                op="intersects",
+                op="within",
             )
 
         cells_copy = tessellation[[unique_id, tessellation.geometry.name]].merge(
@@ -667,30 +653,21 @@ class Blocks:
                 cells_copy.dissolve(by="component").explode().reset_index(drop=True)
             )
         blocks[id_name] = range(len(blocks))
-        blocks[blocks.geometry.name] = gpd.GeoSeries(
-            pygeos.polygons(blocks.exterior.values.data), crs=blocks.crs
-        )
         blocks = blocks[[id_name, blocks.geometry.name]]
 
         if GPD_10:
             centroids_w_bl_ID2 = gpd.sjoin(
-                buildings_c, blocks, how="left", predicate="intersects"
+                buildings_c, blocks, how="left", predicate="within"
             )
         else:
-            centroids_w_bl_ID2 = gpd.sjoin(
-                buildings_c, blocks, how="left", op="intersects"
-            )
-        bl_ID_to_uID = centroids_w_bl_ID2[[unique_id, id_name]]
+            centroids_w_bl_ID2 = gpd.sjoin(buildings_c, blocks, how="left", op="within")
 
-        buildings_m = buildings[[unique_id]].merge(
-            bl_ID_to_uID, on=unique_id, how="left"
-        )
-        self.buildings_id = buildings_m[id_name]
-        self.buildings_id.index = self.buildings.index
+        self.buildings_id = centroids_w_bl_ID2[id_name]
 
         cells_m = tessellation[[unique_id]].merge(
-            bl_ID_to_uID, on=unique_id, how="left"
+            centroids_w_bl_ID2[[unique_id, id_name]], on=unique_id, how="left"
         )
+
         self.tessellation_id = cells_m[id_name]
         self.tessellation_id.index = self.tessellation.index
 
@@ -935,46 +912,59 @@ def get_network_ratio(df, edges, initial_buffer=500):
 
     """
 
-    # intersection-based join
-    buff = edges.buffer(0.01)  # to avoid floating point error
-    inp, res = buff.sindex.query_bulk(df.geometry, predicate="intersects")
-    intersections = (
-        df.iloc[inp]
-        .reset_index(drop=True)
-        .intersection(buff.iloc[res].reset_index(drop=True))
+    if not GPD_10:
+        raise ImportError("`get_network_ratio` requires geopandas 0.10 or newer.")
+
+    (df_ix, edg_ix), dist = edges.sindex.nearest(
+        df.geometry, max_distance=initial_buffer, return_distance=True
     )
+
+    touching = dist < 0.1
+
+    intersections = (
+        df.iloc[df_ix[touching]]
+        .intersection(edges.buffer(0.0001).iloc[edg_ix[touching]], align=False)
+        .reset_index()
+    )
+
     mask = intersections.area > 0.0001
-    intersections = intersections[mask]
-    inp = inp[mask]
-    lengths = intersections.area
-    grouped = lengths.groupby(inp)
+
+    df_ix_touching = df_ix[touching][mask]
+    lengths = intersections[mask].area
+    grouped = lengths.groupby(df_ix_touching)
     totals = grouped.sum()
     ints_vect = []
     for name, group in grouped:
         ratios = group / totals.loc[name]
-        ints_vect.append({res[item[0]]: item[1] for item in ratios.iteritems()})
+        ints_vect.append(
+            {edg_ix[touching][item[0]]: item[1] for item in ratios.iteritems()}
+        )
 
-    edge_dicts = pd.Series(ints_vect, index=totals.index)
+    ratios = pd.Series(ints_vect, index=df.index[list(grouped.groups.keys())])
 
-    # nearest neighbor join
-    nans = df.index.difference(edge_dicts.index)
-    buffered = df.iloc[nans].buffer(initial_buffer)
-    additional = []
+    near = []
+    df_ix_non = df_ix[~touching]
+    grouped = pd.Series(dist[~touching]).groupby(df_ix_non)
+    for name, group in grouped:
+        near.append({edg_ix[~touching][group.idxmin()]: 1.0})
 
-    for orig, geom in zip(df.iloc[nans].geometry, buffered.geometry):
-        query = edges.sindex.query(geom, predicate="intersects")
-        b = initial_buffer
-        while query.size == 0:
-            query = edges.sindex.query(geom.buffer(b), predicate="intersects")
-            b += initial_buffer
-        additional.append({edges.iloc[query].distance(orig).idxmin(): 1})
+    near = pd.Series(near, index=df.index[list(grouped.groups.keys())])
+
+    ratios = pd.concat([ratios, near])
+
+    nans = df[~df.index.isin(ratios.index)]
+    if not nans.empty:
+        df_ix, edg_ix = edges.sindex.nearest(
+            nans.geometry, return_all=False, max_distance=None
+        )
+        additional = pd.Series([{i: 1.0} for i in edg_ix], index=nans.index)
+
+        ratios = pd.concat([ratios, additional])
 
-    additional = pd.Series(additional, index=nans)
-    ratios = pd.concat([edge_dicts, additional]).sort_index()
     result = pd.DataFrame()
     result["edgeID_keys"] = ratios.apply(lambda d: list(d.keys()))
     result["edgeID_values"] = ratios.apply(lambda d: list(d.values()))
-    result.index = df.index
+
     return result
 
 
@@ -1069,10 +1059,9 @@ def enclosures(
             new += list(polygons[within])
 
         final_enclosures = (
-            gpd.GeoSeries(enclosures)
-            .drop(unique)
-            .append(gpd.GeoSeries(new))
-            .reset_index(drop=True)
+            pd.concat(
+                [gpd.GeoSeries(enclosures).drop(unique), gpd.GeoSeries(new)]
+            ).reset_index(drop=True)
         ).set_crs(primary_barriers.crs)
 
         final_enclosures = gpd.GeoDataFrame(
