@@ -4,7 +4,6 @@
 import collections
 import math
 import operator
-from distutils.version import LooseVersion
 import warnings
 
 import geopandas as gpd
@@ -13,6 +12,7 @@ import numpy as np
 import pandas as pd
 import pygeos
 import shapely
+from packaging.version import Version
 from tqdm.auto import tqdm
 
 from .shape import CircularCompactness
@@ -25,7 +25,7 @@ __all__ = [
     "extend_lines",
 ]
 
-GPD_10 = str(gpd.__version__) >= LooseVersion("0.10")
+GPD_10 = Version(gpd.__version__) >= Version("0.10")
 
 
 def preprocess(
@@ -190,6 +190,8 @@ def remove_false_nodes(gdf):
     """
     Clean topology of existing LineString geometry by removal of nodes of degree 2.
 
+    Returns the original gdf if there's no node of degree 2.
+
     Parameters
     ----------
     gdf : GeoDataFrame, GeoSeries, array of pygeos geometries
@@ -270,11 +272,19 @@ def remove_false_nodes(gdf):
         else:
             final = gpd.GeoSeries(new).explode().reset_index(drop=True)
         if isinstance(gdf, gpd.GeoDataFrame):
-            return df.append(
-                gpd.GeoDataFrame({df.geometry.name: final}, geometry=df.geometry.name),
+            return pd.concat(
+                [
+                    df,
+                    gpd.GeoDataFrame(
+                        {df.geometry.name: final}, geometry=df.geometry.name
+                    ),
+                ],
                 ignore_index=True,
             )
-        return df.append(final, ignore_index=True)
+        return pd.concat([df, final], ignore_index=True)
+
+    # if there's nothing to fix, return the original dataframe
+    return gdf
 
 
 class CheckTessellationInput:
@@ -384,7 +394,9 @@ class CheckTessellationInput:
             type_filter = gpd.GeoSeries(intersection).type == "Polygon"
             empty_filter = intersection.is_empty
             overlapping = od_matrix.reset_index(drop=True)[empty_filter ^ type_filter]
-            over_rows = sorted(overlapping.origin.append(overlapping.dest).unique())
+            over_rows = sorted(
+                pd.concat([overlapping.origin, overlapping.dest]).unique()
+            )
 
             self.overlap = gdf.iloc[over_rows]
             overlapping_c = len(self.overlap)
