@@ -75,6 +75,9 @@ class FormFactor:
         the name of the dataframe column, ``np.array``, or ``pd.Series`` where is
         stored area value. If set to ``None``, function will calculate areas
         during the process without saving them separately.
+    heights : str, list, np.array, pd.Series (default None)
+        the name of the dataframe column, ``np.array``, or ``pd.Series`` where height
+        values are stored. Note that it cannot be ``None``.
 
     Attributes
     ----------
@@ -494,7 +497,7 @@ class CircularCompactness:
         radius = hull.apply(
             lambda g: _circle_radius(list(g.coords)) if g is not None else None
         )
-        self.series = areas / (np.pi * radius ** 2)
+        self.series = areas / (np.pi * radius**2)
 
 
 class SquareCompactness:
@@ -1107,7 +1110,7 @@ class Elongation:
         bbox = gdf.geometry.apply(lambda g: g.minimum_rotated_rectangle)
         a = bbox.area
         p = bbox.length
-        cond1 = p ** 2
+        cond1 = p**2
         cond2 = 16 * a
         bigger = cond1 >= cond2
         sqrt = np.empty(len(a))
