@@ -2,13 +2,14 @@
 # -*- coding: utf-8 -*-
 
 import math
+import warnings
 
 import geopandas as gpd
 import libpysal
 import networkx as nx
 import numpy as np
-
-from shapely.geometry import Point
+from numpy.lib import NumpyVersion
+from shapely.geometry import Point, LineString
 
 
 __all__ = [
@@ -40,18 +41,13 @@ def unique_id(objects):
 
 def _angle(a, b, c):
     """
-    Measure angle between a-b, b-c. In radians.
+    Measure angle between a-b, b-c. In degrees.
     Helper for gdf_to_nx.
+    Adapted from cityseer's implementation.
     """
-    ba = [aa - bb for aa, bb in zip(a, b)]
-    bc = [cc - bb for cc, bb in zip(c, b)]
-    nba = math.sqrt(sum((x ** 2.0 for x in ba)))
-    ba = [x / nba for x in ba]
-    nbc = math.sqrt(sum((x ** 2.0 for x in bc)))
-    bc = [x / nbc for x in bc]
-    scal = sum((aa * bb for aa, bb in zip(ba, bc)))
-    angle = math.acos(round(scal, 10))
-    return angle
+    a1 = math.degrees(math.atan2(b[1] - a[1], b[0] - a[0]))
+    a2 = math.degrees(math.atan2(c[1] - b[1], c[0] - b[0]))
+    return abs((a2 - a1 + 180) % 360 - 180)
 
 
 def _generate_primal(G, gdf_network, fields, multigraph):
@@ -60,8 +56,24 @@ def _generate_primal(G, gdf_network, fields, multigraph):
     Helper for gdf_to_nx.
     """
     G.graph["approach"] = "primal"
+
+    msg = "%s. This can lead to unexpected behaviour. The intended usage of the conversion function is with networks made of LineStrings only."
+
+    if not "LineString" in gdf_network.geom_type.unique():
+        warnings.warn(
+            message=msg % "The given network does not contain any LineString.",
+            category=RuntimeWarning,
+        )
+
+    if len(gdf_network.geom_type.unique()) > 1:
+        warnings.warn(
+            message=msg % "The given network consists of multiple geometry types.",
+            category=RuntimeWarning,
+        )
+
     key = 0
     for row in gdf_network.itertuples():
+
         first = row.geometry.coords[0]
         last = row.geometry.coords[-1]
 
@@ -441,16 +453,24 @@ def limit_range(vals, rng):
     array
         limited array
     """
+
     vals = np.asarray(vals)
-    if len(vals) > 2:
-        rng = sorted(rng)
-        if np.isnan(vals).any():
-            lower = np.nanpercentile(vals, rng[0], interpolation="nearest")
-            higher = np.nanpercentile(vals, rng[1], interpolation="nearest")
+    nan_tracker = np.isnan(vals)
+
+    if (len(vals) > 2) and (not nan_tracker.all()):
+        if NumpyVersion(np.__version__) >= "1.22.0":
+            method = dict(method="nearest")
         else:
-            lower = np.percentile(vals, rng[0], interpolation="nearest")
-            higher = np.percentile(vals, rng[1], interpolation="nearest")
-        return vals[(lower <= vals) & (vals <= higher)]
+            method = dict(interpolation="nearest")
+        rng = sorted(rng)
+        if nan_tracker.any():
+            lower = np.nanpercentile(vals, rng[0], **method)
+            higher = np.nanpercentile(vals, rng[1], **method)
+        else:
+            lower = np.percentile(vals, rng[0], **method)
+            higher = np.percentile(vals, rng[1], **method)
+        vals = vals[(lower <= vals) & (vals <= higher)]
+
     return vals
 
 
